@@ -116,6 +116,10 @@ namespace facter { namespace facts {
          * The fact for IPv6 network.
          */
         constexpr static char const* network6 = "network6";
+        /**
+         * The fact for IPv6 scope.
+         */
+        constexpr static char const* scope6 = "scope6";
         /**
          * The fact for interface MAC address.
          */
@@ -446,6 +450,11 @@ namespace facter { namespace facts {
          */
         constexpr static char const* windows_release_id = "windows_release_id";
 
+        /**
+         * The fact for Windows Display Version.
+         */
+        constexpr static char const* windows_display_version = "windows_display_version";
+
         /**
          * The fact for Windows native system32 directory.
          */
@@ -611,6 +620,11 @@ namespace facter { namespace facts {
          */
         constexpr static char const* solaris_zones = "solaris_zones";
 
+        /**
+         * The fact for Azure metadata.
+         */
+        constexpr static char const* az_metadata = "az_metadata";
+
         /**
          * The fact for EC2 metadata.
          */
